Contributors
============

IFermi was developed by **Amy Searle** |ajsearle| and
**Alex Ganose** |utf| |0000-0002-4486-3321|.
The project was designed and led by **Sinéad Griffin** |0000-0002-9943-4866| at Lawrence
Berkeley National Laboratory.


.. |ajsearle| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/ajsearle97
   :width: 16
   :height: 16
   :alt: GitHub profile for utf
.. |0000-0002-9943-4866| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-9943-4866
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-9943-4866
.. |utf| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/utf
   :width: 16
   :height: 16
   :alt: GitHub profile for utf
.. |0000-0002-4486-3321| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0002-4486-3321
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0002-4486-3321

Additional contributions have been provided by:

| **Matthew Horton** |mkhorton| |0000-0001-7777-8871|
| Project Scientist, Persson Group
| Lawrence Berkeley National Laboratory

.. |mkhorton| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/mkhorton
   :width: 16
   :height: 16
   :alt: GitHub commits from mkhorton

.. |0000-0001-7777-8871| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-7777-8871
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-7777-8871

| **Mariano Forti** |mdforti| |0000-0001-7366-3372|
| Postdoctoral Researcher
| Interdisciplinary Centre for Advanced Materials Simulation

.. |mdforti| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/mdforti
   :width: 16
   :height: 16
   :alt: GitHub commits from mdforti
.. |0000-0001-7366-3372| image:: _static/orcid.svg
   :target: https://orcid.org/0000-0001-7366-3372
   :width: 16
   :height: 16
   :alt: ORCID profile for 0000-0001-7366-3372
